CREATE OR REPLACE FUNCTION UYE.SF_MAKBUZIPTAL  (
           al_GeciciMakbuzSiraNo in Number,
           al_IptalNedeni in Varchar2,
           as_ErrMsg            out Varchar2
         ) RETURN Number IS


/*AUTHOR    :   GKTAN ELGIN
PURPOSE     :   Kesilen makbuzu iptal eden bir fonksiyondur. Bu fonksiyon
                Makbuz tablosunda ilgili makbuzun iptal bayragini kaldirir ve
                Makbuz detaydaki ilgili kayitlari siler bylece tahakkuk eski haline geri
                dnms olacaktir
UPDATE      :   18.11.2002
Update      :   23.01.2006    CG@
Update      :   27.08.2012    GE(dg)  yeni MAKBUZVEZNE tablosu iin bir ekleme
*/
--Okunan tm MakbuzDetay kayitlari bu diziye aktarilmakta

  TYPE DetayTahakkuk_Array IS TABLE OF  NUMBER
    INDEX BY BINARY_INTEGER;

  la_DetayTahakkuk   DetayTahakkuk_Array ;

  ln_TahakkukSiraNo    Number;
  ln_i                 Number;
  ln_ErrCode           Number;
  ln_MuhIslemNumarasi  Number;
  ln_FisNo             Number;

  ls_PesinOdemeli      Varchar2(1);

  ln_DetayIndex        Number Default  0;

  No_Error             Number Default  1;
  Be_Error             Number Default -1;

  ls_Mantkisal_TRUE    Varchar2(1) Default '1';
  ls_aciklama           Varchar2(255);
  ls_tahakkuktipkodu   Varchar2(5);


  -- Makbuzla iliskili makbuzdetay kayitlarinin ve iliskili olduklari tahakkuklari
  --    okuyan cursor
  cursor makbuzdetay_cur is
    SELECT tahakkuksirano FROM UYE.MakbuzDetay
      WHERE GeciciMakbuzSiraNo=al_GeciciMakbuzSiraNo;

BEGIN

  as_ErrMsg := '';

  -- Geici makbuz sirrano bilgisi geerli mi kontrol yapilmakta
    IF al_GeciciMakbuzSiraNo >0 THEN
        null;
    ELSE
    as_ErrMsg := 'Eksik Parametre:"GeiciMakbuzSiraNo" Bilgisini Girmelisiniz';
    Return Be_Error;
    END IF;

  -- Muhasebe Islem numarasi okunmakta
  BEGIN
      SELECT MuhIslemNumarasi INTO ln_MuhIslemNumarasi FROM Uye.Makbuz
        WHERE GeciciMakbuzSiraNo = al_GeciciMakbuzSiraNo;
  EXCEPTION
      WHEN OTHERS THEN
        as_ErrMsg := 'Makbuzun Muhasebe Islem Numaarsi Okunamadi.Hata:'||SqlErrM;
        Return Be_Error;
  END;

  -- FisNo Bilgisi Okunmakta. Makbuz muhasebelestirilmis mi kontrol yapilmakta
  BEGIN
      SELECT FisNo INTO ln_FisNo FROM Muh.IslemTablosu
        WHERE IslemNo = ln_MuhIslemNumarasi;
  EXCEPTION
      WHEN OTHERS THEN
        as_ErrMsg := 'Makbuzun Muhasebe Islem Numaarsi Okunamadi.Hata:'||SqlErrM;
        Return Be_Error;
  END;
  IF ln_FisNo >0 THEN
      as_ErrMsg := 'Makbuz Muhasebelestirilmis. Iptal Edemezsiniz';
      Return Be_Error;
  END IF;

  -- Makbuz muhasebelestirilmemis ise muhislem tablosundan kaydi silinmekte
  DELETE Muh.IslemTablosu WHERE IslemNo=ln_MuhIslemNumarasi;

    -- Makbuz Detay kayitlarinin iliskili olduklari tahakkuk bilgileri okunmakta
    open makbuzdetay_cur;
    loop
    fetch makbuzdetay_cur into ln_TahakkukSiraNo;
    exit when makbuzdetay_cur%NOTFOUND;

    -- Okunan makbuz detay kaydi diziye alinmakta. Daha ileride bu dizideki tahakkuksirano bilgileri
    --    kullanilacacktir.
    ln_DetayIndex := ln_DetayIndex +1;
    la_DetayTahakkuk(ln_DetayIndex) := ln_TahakkukSiraNo;
    end loop;
    close makbuzdetay_cur;

    IF ln_DetayIndex=0 THEN
    as_ErrMsg := '"GeiciMakbuzSiraNo ='||to_char(al_GeciciMakbuzSiraNo)||'" Olan Makbuz Detay Kaydi Bulunamadi';
    Return Be_Error;
    END IF;

    -- Makbuzla iliskili makbuz detay kayitlarinin hepsi silinmekte
    begin
    DELETE uye.makbuzdetay WHERE GeciciMakbuzSiraNo = al_GeciciMakbuzSiraNo;
    exception
    When Others THen
      as_ErrMsg := SqlErrM;
      Return Be_Error;
    end;

    -- Makbuz Detaylarin iliskili oldugu tahakkuklar ve onlarin altindaki alt tahakkuklar
    --  gerekiyorsa silinecek.

    FOR ln_i in 1..ln_DetayIndex LOOP
        ln_TahakkukSiraNo := la_DetayTahakkuk(ln_i);
        -- Alt tahakkuklari silinmekte
      BEGIN
        SELECT tahakkuktipkodu INTO ls_tahakkuktipkodu FROM UYE.TAHAKKUK
            WHERE TahakkukSiraNo = ln_TahakkukSiraNo;
         IF ls_tahakkuktipkodu <> '10110' THEN   
            DELETE from uye.tahakkuk WHERE usttahakkuksirano = ln_TahakkukSiraNo;
         END IF;    
         update uye.tahakkuk set tahsiledildi = 0 where tahakkuksirano = ln_TahakkukSiraNo;
      EXCEPTION
         WHEN no_data_found THEN
            ls_tahakkuktipkodu := ''; 
         WHEN OTHERS THEN
            as_ErrMsg  := 'Makbuz Detayla iliskili tahakkuka ait alt tahakkuklar silinemedi.Hata'||SqlErrM;
            ln_ErrCode := SqlCode;
            IF ln_ErrCode = -2292 THEN
               -- Konstrain hatasi olustu demektir.
               as_ErrMsg  := 'Makbuzla Iliskili "'||to_char(ln_TahakkukSiraNo)||'" Nolu Tahakkuka Ait  Alt Tahakkuklardan Bazilarina Makbuz Kesilmis'||
                             chr(13)||'Alt Tahakkuklara Ait Makbuzlari Iptal Ettikten Sonra Terar Deneyiniz '||
                             chr(13)||Chr(13)||'Veritabani Hatasi:'||SqlErrM||
                             chr(13)||Chr(13)||'Islem Tamamlanamadi';

            END IF;
            Return Be_Error;
      END;

      -- Pesin demeli bilgisi okunmakta. Pesin demeli ise ilgili tahakkuk ta silinmekte
      BEGIN
          SELECT PesinOdemeli INTO ls_PesinOdemeli FROM UYE.TAHAKKUK
            WHERE TahakkukSiraNo = ln_TahakkukSiraNo;
        IF ls_PesinOdemeli = ls_Mantkisal_TRUE THEN
           -- Bu gruptaki tahakkuklar aslinda gerek bir tahakkuk ifade etmemektedir.
           -- Bu nedenle de silinmesi gerekmektedir.
           DELETE Uye.Tahakkuk WHERE TahakkukSiraNo = ln_TahakkukSiraNo;
        END IF;
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          null;  -- Tahakkuklardan biri makbuzdetaydaki baska bir tahakkukun birisi olabilmekte.
                 -- Ilgili tahakkukun alt tahakkuklari silinirken bu tahakku ta silinmis demektir.
        WHEN OTHERS THEN
          as_ErrMsg := 'MakbuzDetay Kayitlariyla iliskili Tahakkuk kayitlari silinemedi.Hata'||SqlErrM;
          Return Be_Error;
      END;

    END LOOP ;

    -- Makbuz kayid iptal olarak set edilmekte
  SELECT aciklama into ls_aciklama FROM Uye.Makbuz WHERE GeciciMakbuzSiraNo = al_GeciciMakbuzSiraNo;
  ls_Aciklama := ls_Aciklama || '  IPTAL NEDENI: ' || al_IptalNedeni;
  UPDATE Uye.Makbuz SET Iptal = '1' , Aciklama = ls_Aciklama WHERE GeciciMakbuzSiraNo = al_GeciciMakbuzSiraNo;


  IF SQL%ROWCOUNT <=0 THEN
      as_ErrMsg := 'Makbuz Kaydi Iptal Olarak Gnlenemedi';
      Return Be_Error;
  END IF;

    -- GE 27/08/2012 dg Makbuz iptallerde n vezneden tahakkuklar silinir
  DELETE Uye.MakbuzVezne WHERE GeciciMakbuzSiraNo = al_GeciciMakbuzSiraNo;

  Return No_Error;
EXCEPTION
    WHEN OTHERS THEN
      as_ErrMsg := 'Genel Veritabani Hatasi:'||SqlErrM;
      Return Be_Error;
END;
/
