
CREATE SEQUENCE UYE.SEQ_TAHAKKUK_LOG
  START WITH 10000000
  MAXVALUE 1000000000000000000000000000
  MINVALUE 0
  NOCYCLE
  NOCACHE
  NOORDER;
  

create table uye.tahakkuk_log_temp2 as
select * from uye.tahakkuk_log;


ALTER TABLE UYE.TAHAKKUK_LOG
 DROP PRIMARY KEY CASCADE;
DROP TABLE UYE.TAHAKKUK_LOG CASCADE CONSTRAINTS;


CREATE TABLE UYE.TAHAKKUK_LOG
(
  LOGSIRANO          NUMBER                     NOT NULL,
  LOGTARIHI          DATE                       NOT NULL,
  TAHAKKUKSIRANO     NUMBER                     NOT NULL,
  KULLANICIADI       VARCHAR2(16 BYTE),
  ISLEM              CHAR(1 BYTE),
  TAHAKKUKTIPKODU    CHAR(5 BYTE),
  KURUMNO            INTEGER,
  TESCILSIRANO       INTEGER,
  USTTAHAKKUKSIRANO  NUMBER,
  SALONISLEMSIRANO   INTEGER,
  TAHAKKUKTARIHI     DATE,
  SONODEMETARIHI     DATE,
  TAHAKKUKTIPI       CHAR(1 BYTE),
  TAKSITYILI         NUMBER(4),
  TAKSITNO           INTEGER,
  TUTAR              NUMBER(20,2),
  TAHSILEDILDI       INTEGER,
  AF                 CHAR(1 BYTE),
  CEZAAF             CHAR(1 BYTE),
  ACIKLAMA           VARCHAR2(255 BYTE),
  YAPILANDIRMA       VARCHAR2(1 BYTE),
  ISKONTO            NUMBER
)
NOMONITORING;

CREATE UNIQUE INDEX UYE.PK_TAHAKKUK_LOG ON UYE.TAHAKKUK_LOG
(LOGSIRANO,LOGTARIHI, TAHAKKUKSIRANO, ISLEM)
LOGGING
NOPARALLEL;


ALTER TABLE UYE.TAHAKKUK_LOG ADD (
  CONSTRAINT PK_TAHAKKUK_LOG
 PRIMARY KEY
 (LOGSIRANO,LOGTARIHI, TAHAKKUKSIRANO, ISLEM));


insert into  uye.tahakkuk_log 
select rownum,l.* from uye.tahakkuk_log_temp2 l;


-- Tahakkuk deleted Fields

CREATE OR REPLACE TRIGGER UYE.ad_tahakkuk_tahakkuklog
AFTER DELETE
ON UYE.TAHAKKUK REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
declare
    ls_kullaniciadi varchar2(16);
    ll_logsirano number;
Begin

    -- --------------------------------------------------------------------------- --
    -- Programmers  : Gktan Elgin
    -- Description  : Uye.Tahakkuk tablosundaki silinen kayitlari
    --                Uye.Tahakkuk_Log tablosuna kaydetmektedir.                     --
    -- --------------------------------------------------------------------------- --

     ls_kullaniciadi := ort.tobbnet_standart.get_sessionuser;
     
     select seq_tahakkuk_log.NEXTVAL into ll_logsirano from DUAL;


     INSERT INTO uye.tahakkuk_log
     (logsirano, logtarihi , tahakkuksirano , kullaniciadi , islem , tahakkuktipkodu ,
      kurumno , tescilsirano , usttahakkuksirano ,  salonislemsirano ,
      tahakkuktarihi , sonodemetarihi , tahakkuktipi , taksityili , taksitno ,
      tutar , tahsiledildi , af , cezaaf , aciklama, yapilandirma , iskonto )
      VALUES
      (ll_logsirano,systimestamp, :old.tahakkuksirano , ls_kullaniciadi , 'D', :old.tahakkuktipkodu ,
      :old.kurumno , :old.tescilsirano , :old.usttahakkuksirano ,
      :old.salonislemsirano , :old.tahakkuktarihi , :old.sonodemetarihi ,
      :old.tahakkuktipi , :old.taksityili , :old.taksitno , :old.tutar ,
      :old.tahsiledildi , :old.af , :old.cezaaf , :old.aciklama , 
      :old.yapilandirma , :old.iskonto );

End;
/


-- Tahakkuk Updated Fields




CREATE OR REPLACE TRIGGER UYE.au_tahakkuk_tahakkuklog
AFTER UPDATE
ON UYE.TAHAKKUK REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
declare
    ls_kullaniciadi varchar2(16);
    ll_logsirano number;
Begin

    -- --------------------------------------------------------------------------- --
    -- Programmers  : Gktan Elgin
    -- Date         : 09.04.2015 Last update
    -- Description  : Uye.Tahakkuk tablosundaki kayitlarda yapilan degisiklikleri
    --                Uye.Tahakkuk_Log tablosuna kaydetmektedir.                     --
    -- --------------------------------------------------------------------------- --


     ls_kullaniciadi := ort.tobbnet_standart.get_sessionuser;
     
     select seq_tahakkuk_log.NEXTVAL into ll_logsirano from DUAL;                 
    
     INSERT INTO uye.tahakkuk_log
     (logsirano,logtarihi , tahakkuksirano , kullaniciadi , islem , tahakkuktipkodu ,
      kurumno , tescilsirano , usttahakkuksirano ,  salonislemsirano ,
      tahakkuktarihi , sonodemetarihi , tahakkuktipi , taksityili , taksitno ,
      tutar , tahsiledildi , af , cezaaf , aciklama , yapilandirma , iskonto )
      VALUES
      (ll_logsirano,systimestamp, :old.tahakkuksirano , ls_kullaniciadi , 'U', :old.tahakkuktipkodu ,
      :old.kurumno , :old.tescilsirano , :old.usttahakkuksirano ,
      :old.salonislemsirano , :old.tahakkuktarihi , :old.sonodemetarihi ,
      :old.tahakkuktipi , :old.taksityili , :old.taksitno , :old.tutar ,
      :old.tahsiledildi , :old.af , :old.cezaaf , :old.aciklama ,
      :old.yapilandirma , :old.iskonto );


End;
/

